
#import <UIKit/UIKit.h>


@interface SliderViewController : UIViewController 
{
    /*
     
     An IBOutlet is how you connect variables in your code to user interface
     elements in Interface Builder (IB). By adding the extra "IBOutlet" to the
     beginning of a variable name the variable will now show up in interface 
     builder under the "outlets" of this object. Generally, when you create a
     child of the UIViewController object (as we did here), this object will
     be the "File's Owner" of the NIB file.
     
     A NIB file is an interface builder file that specifies what a "view" (screen)
     should look like. Think of a NIB as a bunch of "freeze-dried" objects. When a
     NIB is loaded (via your code) it instantiates all the objects that it needs
     to build the interface and creates connections between them. These connections
     are created via IBOutlets.
     
     The "File's Owner" is a special object place-holder that is included with every
     NIB. Essentially, a NIB represents an object that contains other objects. When the 
     NIB is loaded ("unfrozen") it has to have an "owner" - an object to give itself to.
     If we open up the "SliderViewController.xib" file we will see that the "File's
     Owner" is in face "SliderViewController". This is essentially the same as saying:
     
     SliderViewController = "SliderViewController.xib";
     
     */
    IBOutlet UITextField* mTextThreshold;
    IBOutlet UISlider* mSliderThreshold;
}

/*
 Similar to an IBOutlet, an IBAction is a method rather than a data member that
 can be hooked up to certain interface events such as button clicks and touches.
 If we look at the "File's Owner" outlets and actions panel we will see that the
 "SliderUpdate:" method is hooked up to the UISlider object's Slider Value Changed
 action.
 */
- (IBAction) SliderUpdate:(id)sender;
@end
